summaryrefslogtreecommitdiffstats
path: root/src/knutdock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/knutdock.cpp')
-rwxr-xr-xsrc/knutdock.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/knutdock.cpp b/src/knutdock.cpp
index ed5204a..2be630c 100755
--- a/src/knutdock.cpp
+++ b/src/knutdock.cpp
@@ -82,7 +82,7 @@ KNutDock::KNutDock(KNutVarData::upsInfoDef* activeUpsInfo, KNutVarData::SettingD
initImage();
- changeKIcon(); // this function calls function tqrepaintIcon
+ changeKIcon(); // this function calls function repaintIcon
}
@@ -102,7 +102,7 @@ KNutDock::~KNutDock(){
void KNutDock::resizeEvent ( TQResizeEvent * ){
initImage();
- changeKIcon(); // this function calls function tqrepaintIcon
+ changeKIcon(); // this function calls function repaintIcon
}
void KNutDock::changeUps (void) {
@@ -117,7 +117,7 @@ void KNutDock::clearDockValues(void){
initImage(); // paints standart icon
clearValues();
- tqrepaintDock(true);
+ repaintDock(true);
}
@@ -133,7 +133,7 @@ void KNutDock::changeKIBColor(void) {
if (!m_settingData->customKIconColor) m_myBGColor = backgroundColor;
else m_myBGColor = m_settingData->kIconBackgroundColor; // uses defined color
- tqrepaintDock(true);
+ repaintDock(true);
}
void KNutDock::changeKIcon (void) {
@@ -166,7 +166,7 @@ void KNutDock::changeKIcon (void) {
m_statusWarningValue = m_statusValue & (KNutNet::CAL | KNutNet::TRIM | KNutNet::BOOST
| KNutNet::OVER | KNutNet::RB);
- tqrepaintDock(true);
+ repaintDock(true);
}
void KNutDock::initImage(void) {
@@ -181,15 +181,15 @@ void KNutDock::setNewUPS(void) {
}
-void KNutDock::tqrepaintDock (const bool always) {
+void KNutDock::repaintDock (const bool always) {
TQString nutStringVar;
int myRuntimeValue;
int myUpsLoadValue;
int myStatusValue;
int myStatusBatValue;
int myBatteryChargeValue;
- bool tqrepaintNow = false;
- // value tqrepaintNow is seted when some ups values are changed
+ bool repaintNow = false;
+ // value repaintNow is seted when some ups values are changed
bool okFloat;
TQString valueName;
TQPainter paint;
@@ -206,7 +206,7 @@ void KNutDock::tqrepaintDock (const bool always) {
if (!m_activeUpsInfo->upsNet->existName(m_activeUpsInfo->runtimeVar)) {
nutStringVar = m_activeUpsInfo->upsNet->readStringVar(m_activeUpsInfo->runtimeVar);
-//std::cout << "KNutDock::tqrepaintDock RUNTIME " << nutStringVar << std::endl;
+//std::cout << "KNutDock::repaintDock RUNTIME " << nutStringVar << std::endl;
if (nutStringVar.isEmpty()) myRuntimeValue=knc::numberVarError;
else {
myRuntimeValue = (int)nutStringVar.toFloat(&okFloat);
@@ -224,7 +224,7 @@ void KNutDock::tqrepaintDock (const bool always) {
if (myStatusValue !=m_statusValue ) {
m_statusValue = myStatusValue;
painttqStatus(m_statusValue);
- tqrepaintNow = true;
+ repaintNow = true;
}
// **********RUNTIME***********
@@ -235,7 +235,7 @@ void KNutDock::tqrepaintDock (const bool always) {
m_runtimeValue = myRuntimeValue; // runtime is old value of runtime, one is defined like global value of class
m_statusBatValue = myStatusBatValue;
paintRuntime(m_runtimeValue, m_statusValue);
- tqrepaintNow = true;
+ repaintNow = true;
}
break;
@@ -245,13 +245,13 @@ void KNutDock::tqrepaintDock (const bool always) {
m_statusValue = myStatusValue;
m_statusWarningValue = myStatusValue & (KNutNet::CAL | KNutNet::TRIM | KNutNet::BOOST
| KNutNet::OVER | KNutNet::RB);
- tqrepaintNow = true;
+ repaintNow = true;
}
// **********RUNTIME***********
if (myRuntimeValue != m_runtimeValue) {
m_runtimeValue = myRuntimeValue;
- tqrepaintNow = true;
+ repaintNow = true;
}
break;
} ///////////////////// end of models
@@ -274,7 +274,7 @@ void KNutDock::tqrepaintDock (const bool always) {
if (myUpsLoadValue != m_upsLoadValue) {
m_upsLoadValue = myUpsLoadValue;
if (m_typeOfIcon == generalKI) paintLoad(m_upsLoadValue);
- tqrepaintNow = true;
+ repaintNow = true;
}
// *********BATTERY CHARGE****************
@@ -293,11 +293,11 @@ void KNutDock::tqrepaintDock (const bool always) {
if (myBatteryChargeValue != m_batteryChargeValue) {
m_batteryChargeValue = myBatteryChargeValue;
if (m_typeOfIcon == generalKI)paintCharge(m_batteryChargeValue);
- tqrepaintNow = true;
+ repaintNow = true;
}
// ************* End of values********************
- if (tqrepaintNow || always || (m_dataOk != m_dataOkOld)) {
+ if (repaintNow || always || (m_dataOk != m_dataOkOld)) {
switch (m_typeOfIcon) {